.. _compatibility:

.. image:: ../artwork/cicada.png
  :width: 200px
  :align: right

Compatibility
=============

A quick disclaimer on backwards-compatibility for Cicada users:

Cicada follows the `Semantic Versioning <http://semver.org>`_ standard for
assigning version numbers in a way that has specific meaning.  Cicada version
numbers follow `<major>.<minor>.<patch>` numbering.  Releases with different
major version numbers are API incompatible.  Minor version numbers signify new
features that are backwards-compatible with the current major version.  Patch
numbers indicate bug fixes and documentation changes that are
backwards-compatible with the current major and minor version.



